package de.unibi.airobots.bonsai.actuators;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.btl.data.annotation.MapAnnotation;

/**
 * An interface for Actuators that publish MapAnnotations
 * 
 * @author vrichter
 */
public interface MapAnnotationActuator extends Actuator {

	/**
	 * Creates and publishes a representation of a MapAnnotation.
	 * 
	 * @param annotation
	 *            This MapAnnotation will be published.
	 */
	public void publish(MapAnnotation annotation);

	/**
	 * After a MapAnnotation was published, this method should be used to update
	 * it. When no MapAnnotation was published before this method throws an
	 * Exception.
	 * 
	 * @param newAnnotation
	 * @throws NoDocumentInsertedException
	 */
	public void update(MapAnnotation newAnnotation)
			throws NoMapAnnotationPublishedException;

	/**
	 * An Exception that is thrown when update is called before a MapAnnotation
	 * was published through the insert-method.
	 * 
	 * @author vrichter
	 * 
	 */
	public class NoMapAnnotationPublishedException extends Exception {

		private static final long serialVersionUID = 1L;

		public NoMapAnnotationPublishedException() {
			super("There is no published MapAnnotation,"
					+ " thus it can not be updated.");
		}

	}
}
