/*
* This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/bonsai
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
* 				Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
* 				Marian Pohling, Lukas Twardon
*/
package de.unibi.airobots.bonsai.core.configuration;

/**
 * One sensor configured by the user in the configuration file.
 * 
 * @author jwienke
 */
public class ConfiguredSensor extends ConfiguredCoreObject {

    private String dataTypeClassName;
    private String sensorClassName;

    /**
     * Returns the class name of the data type the sensor produces as specified
     * in the config.
     * 
     * @return data type class name
     */
    public String getDataTypeClassName() {
        return dataTypeClassName;
    }

    /**
     * Sets the class name of the data type the sensor produces as specified in
     * the config.
     * 
     * @param dataTypeClassName
     *            data type class name
     */
    public void setDataType(String dataTypeClassName) {
        this.dataTypeClassName = dataTypeClassName;
    }

    /**
     * Returns the name of the implementing class for the sensor as specified in
     * the config.
     * 
     * @return sensor class name
     */
    public String getSensorClassName() {
        return sensorClassName;
    }

    /**
     * Sets the name of the implementing class for the sensor as specified in
     * the config.
     * 
     * @param sensorClassName
     *            sensor class name
     */
    public void setSensorClassName(String sensorClassName) {
        this.sensorClassName = sensorClassName;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return "[" + getClass().getSimpleName() + ": key = " + getKey()
                + ", dataTypeClassName = " + dataTypeClassName
                + ", factoryClassName = " + getFactoryClassName()
                + ", sensorOption = " + getOptions() + "]";
    }

}
