/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.this
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 * 				Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 * 				Marian Pohling, Lukas Twardon
 */
package de.unibi.airobots.bonsai.examples;

import de.unibi.airobots.bonsai.actuators.SpeechActuator;
import de.unibi.airobots.bonsai.core.BonsaiManager;
import de.unibi.airobots.bonsai.sensors.PersonSensor;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSeparator;
import javax.swing.JTextArea;
import javax.swing.JToggleButton;
import javax.swing.SwingConstants;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Talking Control based on the BasicRemote for simple Wizard of Oz experiments.
 * 
 * @author fsiepman
 */
public class TalkingRemoteGerman extends JPanel implements ActionListener {

    private static final long serialVersionUID = -1568953221776249995L;
    private static final Logger LOGGER = Logger.getLogger(TalkingRemoteGerman.class);
    // BonSAI Sensors and Actuators
    private SpeechActuator speechActuator;
    private PersonSensor personSensor;
    private String systemPrefix;
    private boolean singleCondition = true;
    private ImageIcon iconFarLeft;
    private ImageIcon iconLeft;
    private ImageIcon iconMiddle;
    private ImageIcon iconRight;
    private ImageIcon iconFarRight;
    private ImageIcon iconLowLeft;
    private ImageIcon iconDown;
    private ImageIcon iconLowRight;
    private JFrame faceFrame;
    private JPanel facePanel;
    private JLabel faceLabel;
    private JTextArea speechtxt;

    public TalkingRemoteGerman() {

        BasicConfigurator.configure();
        LOGGER.info("setting up TalkingRemoteGerman...");

        systemPrefix = System.getenv("prefix");
        if (systemPrefix == null) {
            LOGGER.warn("prefix variable not set. Check your module!");
            LOGGER.info("loading face images from /vol/robocup/trunk");

            iconFarLeft = new ImageIcon("/vol/robocup/trunk/share/faces/face_ganz_left.jpg");
            iconLeft = new ImageIcon("/vol/robocup/trunk/share/faces/face_left.jpg");
            iconMiddle = new ImageIcon("/vol/robocup/trunk/share/faces/face_normal.jpg");
            iconRight = new ImageIcon("/vol/robocup/trunk/share/faces/face_right.jpg");
            iconFarRight = new ImageIcon("/vol/robocup/trunk/share/faces/face_ganz_right.jpg");
            iconLowLeft = new ImageIcon("/vol/robocup/trunk/share/faces/face_down-left.jpg");
            iconDown = new ImageIcon("/vol/robocup/trunk/share/faces/face_down.jpg");
            iconLowRight = new ImageIcon("/vol/robocup/trunk/share/faces/face_down-right.jpg");
            LOGGER.info("loading BonSAI config");
            BonsaiManager.getInstance().configure("/vol/robocup/trunk/etc/bonsai_config/talkingremotegerman.xml");
        } else {

            LOGGER.info("loading face images from prefix");
            iconFarLeft = new ImageIcon(systemPrefix + "/share/faces/face_ganz_left.jpg");
            iconLeft = new ImageIcon(systemPrefix + "/share/faces/face_left.jpg");
            iconMiddle = new ImageIcon(systemPrefix + "/share/faces/face_normal.jpg");
            iconRight = new ImageIcon(systemPrefix + "/share/faces/face_right.jpg");
            iconFarRight = new ImageIcon(systemPrefix + "/share/faces/face_ganz_right.jpg");
            iconLowLeft = new ImageIcon(systemPrefix + "/share/faces/face_down-left.jpg");
            iconDown = new ImageIcon(systemPrefix + "/share/faces/face_down.jpg");
            iconLowRight = new ImageIcon(systemPrefix + "/share/faces/face_down-right.jpg");
            LOGGER.info("loading BonSAI config");
            BonsaiManager.getInstance().configure(systemPrefix + "/etc/bonsai_config/talkingremotegerman.xml");
        }
        LOGGER.info("Creating SpeechActuator");
        speechActuator = BonsaiManager.getInstance().createActuator("SpeechActuator", SpeechActuator.class);

        LOGGER.info("Creating PersonSensor");
  //      personSensor = (PersonSensor) BonsaiManager.getInstance().createSensor("PersonSensor", PersonList.class);

        LOGGER.info("Setting up the GUI...");
        this.setUpGUI();
        LOGGER.info("The GUI is ready.");
    }

    public static void main(String[] args) {

        try {
            TalkingRemoteGerman remote = new TalkingRemoteGerman();
        } catch (Exception e) {
            e.printStackTrace();
            System.exit(-1);
        }
    }

    @Override
    public void actionPerformed(ActionEvent e) {

        if (e.getActionCommand().equals("Single Person")) {
            LOGGER.info("Single Person set.");
            singleCondition = true;

        } else if (e.getActionCommand().equals("2++ Persons")) {
            LOGGER.info("Single Person unset.");
            singleCondition = false;

        } else if (e.getActionCommand().equals("Begrüßen")) {

            if (singleCondition) {
                try {
                    LOGGER.info("Greeting for single condition");
                    speechActuator.say("Hallo. Mein Name ist Biron. Und wie heißt du?");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Reason: " + ex.getMessage());
                }
            } else {
                try {
                    LOGGER.info("Greeting for multiple persons.");
                    speechActuator.say("Hallo. Mein Name ist Biron. Und wie heißt ihr?");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Reason: " + ex.getMessage());
                }

            }

        } else if (e.getActionCommand().equals("Text ausgeben!")) {
            String textToSay = "";
            if (speechtxt.getText() != null) {
                
                textToSay = speechtxt.getText();
            }
            try {
                LOGGER.info("Text said: " + textToSay);
                speechActuator.say(textToSay);
            } catch (IOException ex) {
                LOGGER.error("Could not speak. Exception: " + ex.getMessage());
            }

        } else if (e.getActionCommand().equals("stark links")) {
            LOGGER.info("Face set to stark links");
            changeFace(iconFarLeft);

        } else if (e.getActionCommand().equals("links")) {
            LOGGER.info("Face set to links");
            changeFace(iconLeft);

        } else if (e.getActionCommand().equals("mitte")) {
            LOGGER.info("Face set to mitte");
            changeFace(iconMiddle);

        } else if (e.getActionCommand().equals("rechts")) {
            LOGGER.info("Face set to rechts");
            changeFace(iconRight);

        } else if (e.getActionCommand().equals("stark rechts")) {
            LOGGER.info("Face set to stark rechts");
            changeFace(iconFarRight);

        } else if (e.getActionCommand().equals("unten links")) {
            LOGGER.info("Face set to unten links");
            changeFace(iconLowLeft);

        } else if (e.getActionCommand().equals("unten")) {
            LOGGER.info("Face set to unten");
            changeFace(iconDown);

        } else if (e.getActionCommand().equals("unten rechts")) {
            LOGGER.info("Face set to unten rechts");
            changeFace(iconLowRight);

        } else if (e.getActionCommand().equals("Wie bitte?")) {
            try {
                LOGGER.info("Saying \"Wie bitte?\"");
                speechActuator.say("Wie bitte?");
            } catch (IOException ex) {
                LOGGER.error("Could not speak. Exception: " + ex.getMessage());
            }

        } else if (e.getActionCommand().equals("Wort unbekannt!")) {
            try {
                LOGGER.info("Saying \"Ich kenne das Wort nicht.\"");
                speechActuator.say("Ich kenne das Wort nicht.");
            } catch (IOException ex) {
                LOGGER.error("Could not speak. Exception: " + ex.getMessage());
            }

        } else if (e.getActionCommand().equals("schonmal gezeigt?")) {
            if (singleCondition) {
                try {
                    LOGGER.info("Saying \"Hast du mir das Objekt schon einmal gezeigt?\"");
                    speechActuator.say("Hast du mir das Objekt schon einmal gezeigt?");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            } else {
                try {
                    LOGGER.info("Saying \"Habt ihr mir das Objekt schon einmal gezeigt?\"");
                    speechActuator.say("Habt ihr mir das Objekt schon einmal gezeigt?");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            }

        } else if (e.getActionCommand().equals("teilweise verstanden")) {
            if (singleCondition) {
                try {
                    LOGGER.info("Saying \"Ich habe dich nur teilweise verstanden. Kannst du das bitte noch einmal wiederholen?\"");
                    speechActuator.say("Ich habe dich nur teilweise verstanden. Kannst du das bitte noch einmal wiederholen?");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            } else {
            try {
                    LOGGER.info("Saying \"Ich habe euch nur teilweise verstanden. Könnt ihr das bitte noch einmal wiederholen?\"");
                    speechActuator.say("Ich habe euch nur teilweise verstanden. Könnt ihr das bitte noch einmal wiederholen?");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            }
            
        } else if (e.getActionCommand().equals("Ball")) {
            try {
                    LOGGER.info("Saying \"Das ist ein Ball.\"");
                    speechActuator.say("Das ist ein Ball.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Tasse")) {
            try {
                    LOGGER.info("Saying \"Das ist eine Tasse.\"");
                    speechActuator.say("Das ist eine Tasse.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Schere")) {
            try {
                    LOGGER.info("Saying \"Das ist eine Schere.\"");
                    speechActuator.say("Das ist eine Schere.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Buch")) {
            try {
                    LOGGER.info("Saying \"Das ist ein Buch.\"");
                    speechActuator.say("Das ist ein Buch.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Glas")) {
            try {
                    speechActuator.say("Das ist ein Glas.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Teller")) {
            try {
                    LOGGER.info("Saying \"Das ist ein Teller.\"");
                    speechActuator.say("Das ist ein Teller.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Schüssel")) {
            try {
                    LOGGER.info("Saying \"Das ist eine Schüssel.\"");
                    speechActuator.say("Das ist eine Schüssel.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Löffel")) {
            try {
                    LOGGER.info("Saying \"Das ist ein Löffel.\"");
                    speechActuator.say("Das ist ein Löffel.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Lineal")) {
            try {
                    LOGGER.info("Saying \"Das ist ein Lineal.\"");
                    speechActuator.say("Das ist ein Lineal.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Schlüssel")) {
            try {
                    LOGGER.info("Saying \"Das ist ein Schlüssel.\"");
                    speechActuator.say("Das ist ein Schlüssel.");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        } else if (e.getActionCommand().equals("Verabschieden")) {
            try {
                    LOGGER.info("Saying \"Auf Wiedersehen. Es hat mir großen Spaß gemacht!\"");
                    speechActuator.say("Auf Wiedersehen. Es hat mir großen Spaß gemacht!");
                } catch (IOException ex) {
                    LOGGER.error("Could not speak. Exception: " + ex.getMessage());
                }
            
        }
    }

    private void setUpGUI() {
        JFrame gui = new JFrame("TalkingRemoteGerman");
        gui.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        gui.setLocation(100, 100);

        facePanel = new JPanel();
        facePanel.setBackground(Color.LIGHT_GRAY);

        faceFrame = new JFrame("Robot Face");
        faceFrame.setUndecorated(true);
        faceFrame.setSize(800, 600);

        faceLabel = new JLabel(iconMiddle);
        facePanel.add(faceLabel);
        faceFrame.getContentPane().add(facePanel);

        ButtonGroup conditionGroup = new ButtonGroup();
        ButtonGroup faceViews = new ButtonGroup();
        ButtonGroup dialogObjects = new ButtonGroup();

        JToggleButton experimentConditionSingle = new JToggleButton("Single Person", true);
        experimentConditionSingle.addActionListener(this);
        conditionGroup.add(experimentConditionSingle);

        JToggleButton experimentConditionPlural = new JToggleButton("2++ Persons", false);
        experimentConditionPlural.addActionListener(this);
        conditionGroup.add(experimentConditionPlural);

        JButton greetButton = new JButton("Begrüßen");
        greetButton.addActionListener(this);

        speechtxt = new JTextArea("Herzlich willkommen!", 1, 10);

        JButton sayButton = new JButton("Text ausgeben!");
        sayButton.addActionListener(this);

        JToggleButton faceFarLeft = new JToggleButton("stark links", false);
        faceFarLeft.addActionListener(this);
        faceViews.add(faceFarLeft);

        JToggleButton faceLeft = new JToggleButton("links", false);
        faceLeft.addActionListener(this);
        faceViews.add(faceLeft);

        JToggleButton faceMiddle = new JToggleButton("mitte", true);
        faceMiddle.addActionListener(this);
        faceViews.add(faceMiddle);

        JToggleButton faceRight = new JToggleButton("rechts", false);
        faceRight.addActionListener(this);
        faceViews.add(faceRight);

        JToggleButton faceFarRight = new JToggleButton("stark rechts", false);
        faceFarRight.addActionListener(this);
        faceViews.add(faceFarRight);

        JToggleButton faceLowLeft = new JToggleButton("unten links", false);
        faceLowLeft.addActionListener(this);
        faceViews.add(faceLowLeft);

        JToggleButton faceDown = new JToggleButton("unten", false);
        faceDown.addActionListener(this);
        faceViews.add(faceDown);

        JToggleButton faceLowRight = new JToggleButton("unten rechts", false);
        faceLowRight.addActionListener(this);
        faceViews.add(faceLowRight);

        JButton pardonButton = new JButton("Wie bitte?");
        pardonButton.addActionListener(this);

        JButton unknownWordButton = new JButton("Wort unbekannt!");
        unknownWordButton.addActionListener(this);

        JButton alreadyShownButton = new JButton("schonmal gezeigt?");
        alreadyShownButton.addActionListener(this);

        JButton partlyUnderstoodButton = new JButton("teilweise verstanden");
        partlyUnderstoodButton.addActionListener(this);

        JToggleButton objectBallButton = new JToggleButton("Ball", true);
        objectBallButton.addActionListener(this);
        dialogObjects.add(objectBallButton);

        JToggleButton objectCupButton = new JToggleButton("Tasse", false);
        objectCupButton.addActionListener(this);
        dialogObjects.add(objectCupButton);

        JToggleButton objectScissorsButton = new JToggleButton("Schere", false);
        objectScissorsButton.addActionListener(this);
        dialogObjects.add(objectScissorsButton);

        JToggleButton objectBookButton = new JToggleButton("Buch", false);
        objectBookButton.addActionListener(this);
        dialogObjects.add(objectBookButton);

        JToggleButton objectGlassButton = new JToggleButton("Glas", false);
        objectGlassButton.addActionListener(this);
        dialogObjects.add(objectGlassButton);

        JToggleButton objectPlateButton = new JToggleButton("Teller", false);
        objectPlateButton.addActionListener(this);
        dialogObjects.add(objectPlateButton);

        JToggleButton objectBowlButton = new JToggleButton("Schüssel", false);
        objectBowlButton.addActionListener(this);
        dialogObjects.add(objectBowlButton);

        JToggleButton objectKeysButton = new JToggleButton("Schlüssel", false);
        objectKeysButton.addActionListener(this);
        dialogObjects.add(objectKeysButton);

        JToggleButton objectSpoonButton = new JToggleButton("Löffel", false);
        objectSpoonButton.addActionListener(this);
        dialogObjects.add(objectSpoonButton);

        JToggleButton objectRulerButton = new JToggleButton("Lineal", false);
        objectRulerButton.addActionListener(this);
        dialogObjects.add(objectRulerButton);

        JButton dismissButton = new JButton("Verabschieden");
        dismissButton.addActionListener(this);

        Container pane = gui.getContentPane();
        GridBagLayout gbl = new GridBagLayout();
        pane.setLayout(gbl);

        //TODO: add components to GUI.
        // cont, gbl, comp, x, y, width, height, weightx, weighty
        addComponent(pane, gbl, new JLabel("Kondition:", SwingConstants.RIGHT), 1, 0, 1, 1, 1.0, 0);
        addComponent(pane, gbl, experimentConditionSingle, 2, 0, 1, 1, 1.0, 0);
        addComponent(pane, gbl, experimentConditionPlural, 3, 0, 1, 1, 1.0, 0);

        addComponent(pane, gbl, new JLabel(" "), 0, 1, 1, 1, 0, 0);
        addComponent(pane, gbl, greetButton, 3, 2, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel(" "), 0, 3, 1, 1, 0, 0);
        addComponent(pane, gbl, new JLabel("Text eingeben:", SwingConstants.RIGHT), 1, 4, 1, 1, 1.0, 0);
        addComponent(pane, gbl, speechtxt, 2, 4, 3, 1, 1.0, 0);
        addComponent(pane, gbl, sayButton, 5, 4, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JSeparator(SwingConstants.HORIZONTAL), 1, 5, 5, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel("Blickrichtung", SwingConstants.CENTER), 3, 6, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel(" "), 0, 7, 1, 1, 0, 0);
        addComponent(pane, gbl, faceFarLeft, 1, 8, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceLeft, 2, 8, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceMiddle, 3, 8, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceRight, 4, 8, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceFarRight, 5, 8, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceLowLeft, 2, 9, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceDown, 3, 9, 1, 1, 1.0, 0);
        addComponent(pane, gbl, faceLowRight, 4, 9, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JSeparator(SwingConstants.HORIZONTAL), 1, 10, 5, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel("Äusserungen", SwingConstants.CENTER), 3, 11, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel(" "), 0, 12, 1, 1, 0, 0);
        addComponent(pane, gbl, pardonButton, 2, 13, 1, 1, 1.0, 0);
        addComponent(pane, gbl, alreadyShownButton, 4, 13, 1, 1, 1.0, 0);
        addComponent(pane, gbl, unknownWordButton, 2, 14, 1, 1, 1.0, 0);
        addComponent(pane, gbl, partlyUnderstoodButton, 4, 14, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JSeparator(SwingConstants.HORIZONTAL), 1, 15, 5, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel("Objekte", SwingConstants.CENTER), 3, 16, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel(" "), 0, 17, 1, 1, 0, 0);
        addComponent(pane, gbl, objectBallButton, 1, 18, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectBookButton, 2, 18, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectBowlButton, 3, 18, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectCupButton, 4, 18, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectGlassButton, 5, 18, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectKeysButton, 1, 19, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectPlateButton, 2, 19, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectScissorsButton, 3, 19, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectSpoonButton, 4, 19, 1, 1, 1.0, 0);
        addComponent(pane, gbl, objectRulerButton, 5, 19, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JSeparator(SwingConstants.HORIZONTAL), 1, 20, 5, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel("Ende", SwingConstants.CENTER), 3, 21, 1, 1, 1.0, 0);
        addComponent(pane, gbl, new JLabel(" "), 0, 22, 1, 1, 0, 0);
        addComponent(pane, gbl, dismissButton, 3, 23, 1, 1, 0, 0);

        gui.pack();
        faceFrame.pack();
        gui.setVisible(true);
        faceFrame.setVisible(true);

    }

    private static void addComponent(Container cont, GridBagLayout gbl,
            Component c, int x, int y, int width, int height, double weightx,
            double weighty) {
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.fill = GridBagConstraints.BOTH;
        gbc.gridx = x;
        gbc.gridy = y;
        gbc.gridwidth = width;
        gbc.gridheight = height;
        gbc.weightx = weightx;
        gbc.weighty = weighty;
        gbl.setConstraints(c, gbc);
        cont.add(c);
    }

    private void changeFace(ImageIcon icon) {

        faceLabel.setIcon(icon);
        faceFrame.repaint();
    }
}
