/*
* This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/bonsai
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
* 				Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
* 				Marian Pohling, Lukas Twardon
*/
package de.unibi.airobots.bonsai.sensors.data;

import javax.media.opengl.GL;

/**
 * The PlaneType of the image used by ImageData class.
 * 
 * @author Ingo Luetkebohle <iluetkeb@techfak.uni-bielefeld.de>
 * @author vrichter
 */
public enum PlaneType {
    
    UNKNOWN_RAW8, GRAY8, GRAY16, PLANAR_RGB8, PLANAR_RGB32, PLANAR_YUV8, INTERLEAVED_RGB8;

    private static final int[] GL_1L = new int[] { GL.GL_LUMINANCE };
    private static final int[] GL_3L =
            new int[] { GL.GL_LUMINANCE, GL.GL_LUMINANCE, GL.GL_LUMINANCE };
    private static final int[] GL_1RGB = new int[] { GL.GL_RGB };

    public static int[] getGLPlaneTypes(PlaneType type) {
        switch (type) {
        case UNKNOWN_RAW8:
        case GRAY8:
        case GRAY16:
            return GL_1L;
        case PLANAR_RGB8:
        case PLANAR_RGB32:
        case PLANAR_YUV8:
            return GL_3L;
        case INTERLEAVED_RGB8:
            return GL_1RGB;
        default:
            return GL_1L;
        }
    }

    public static final int getNumPlanes(PlaneType type) {
        return getGLPlaneTypes(type).length;
    }
}
