/*
* This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/bonsai
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
* 				Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
* 				Marian Pohling, Lukas Twardon
*/
package de.unibi.airobots.bonsai.util.reflection;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.apache.log4j.Logger;

// CHECKSTYLE:OFF this is what the class is supposed to do, using a proprietary
// mechanism for class retrieval. So this import isn't illegal here.
import sun.misc.Service; // CHECKSTYLE:ON

/**
 * An implementation of {@link ServiceDiscovery} that uses the jar file services
 * mechanism to find services.
 * 
 * @see <a
 *      href="http://java.sun.com/javase/6/docs/technotes/guides/jar/jar.html#Service%20Provider">JAR
 *      File Specification - Service Provider</a>
 * @author jwienke
 */
public class JarServiceDiscovery implements ServiceDiscovery {

    private Logger logger = Logger.getLogger(getClass());

    @SuppressWarnings("unchecked")
    @Override
    public <T> Set<Class<? extends T>> discoverServicesByInterface(
            Class<T> iFace) {

        logger.info("Discovering JAR services for interface " + iFace);

        Set<Class<? extends T>> classes = new HashSet<Class<? extends T>>();

        Iterator ps = Service.providers(iFace);
        while (ps.hasNext()) {
            T t = (T) ps.next();
            Class<?> clazz = t.getClass();
            logger.debug("Discovered service class " + clazz);
            classes.add((Class<T>) clazz);
        }

        logger.info("Discovered instances of " + iFace + ": " + classes);

        return classes;

    }

}
