package de.unibi.airobots.bonsai.xcf.actuators;

import java.io.IOException;

import org.apache.log4j.Logger;

import net.sf.xcf.ActiveMemory;
import net.sf.xcf.memory.MemoryException;
import net.sf.xcf.transport.XOPData;
import nu.xom.Builder;
import nu.xom.Node;
import nu.xom.ParsingException;
import nu.xom.ValidityException;
import de.unibi.airobots.bonsai.actuators.MapAnnotationActuator;
import de.unibi.airobots.bonsai.xcf.ActiveMemoryReconnectable;
import de.unibi.airobots.btl.data.annotation.MapAnnotation;

public class XcfMapAnnotationActuator implements ActiveMemoryReconnectable,
		MapAnnotationActuator {

	private Logger logger = Logger.getLogger(getClass());

	private static Builder builder = new Builder();

	private String memoryName = "";
	private Object memoryLock = new Object();
	private ActiveMemory memory = null;

	/**
	 * The XOPData that describes the Document that was inserted at the memory
	 * last time. This will be used for calls of update, which replace the
	 * current document on the Memory with a new one, that holds the same
	 * DBXML:ID.
	 */
	private XOPData document;

	/**
	 * Constructor.
	 * 
	 * @param memoryName
	 *            name of the active memory to write the MapAnnotation to.
	 */
	public XcfMapAnnotationActuator(String memoryName) {
		this.memoryName = memoryName;
		logger.debug("Create memory sensor for memoryName " + memoryName);
	}

	@Override
	public void publish(MapAnnotation annotation) {
		synchronized (memoryLock) {
			if (document != null) {
				logger.info("A MapAnnotation with was inserted before. "
						+ "Now working with a new Document.");
			}
			XOPData data = null;
			try {
				data = createXOPData();

				if (data == null) {
					logger.error("Could not create new XOPData. "
							+ "Not inserting MapAnnotation.");
					return;
				}

				annotation.fillInto(data.getDocument().getRootElement());

				logger.info("Inserting into AM: " + data.getDocumentAsText());
				document = memory.insert(data);

			} catch (MemoryException e) {
				logger.info("Exception while inserting at memory");
				e.printStackTrace();
			}
		}
	}

	/**
	 * Creates a new XOPData representing a MapAnnotation.
	 * 
	 * @return
	 */
	private XOPData createXOPData() {
		XOPData ret = null;
		try {
			ret = new XOPData(builder.build("<" + MapAnnotation.getBaseTag()
					+ "/>", null));
		} catch (ValidityException e) {
			logger.error("Exception while creating new XOPData");
			e.printStackTrace();
		} catch (ParsingException e) {
			logger.error("Exception while creating new XOPData");
			e.printStackTrace();
		} catch (IOException e) {
			logger.error("Exception while creating new XOPData");
			e.printStackTrace();
		}
		return ret;
	}

	@Override
	public void update(MapAnnotation newAnnotation)
			throws NoMapAnnotationPublishedException {

		synchronized (memoryLock) {
			if (document == null) {
				throw new NoMapAnnotationPublishedException();
			}
			if (document.getDocument().getChildCount() != 1) {
				logger
						.info("Child count of MapAnnotationDocument =! " + 1
								+ "(is "
								+ document.getDocument().getChildCount() + ")");
			}
			Node node = document.getDocument().getRootElement().getChild(0);
			logger.info("Removing node :" + node.toString());
			document.getDocument().getRootElement().removeChild(0);
			logger.info("Document is now: " + document.getDocumentAsText());
			newAnnotation.fillInto(document.getDocument().getRootElement());
			logger.info("Replacing Document with: " + document.toString());
			
			try {
				memory.replace(document);
			} catch (MemoryException e) {
				logger.info("Exception while replacing in memory");
				e.printStackTrace();
			}
		}
	}

	@Override
	public String getActiveMemoryName() {
		return this.memoryName;
	}

	@Override
	public void resetActiveMemory(ActiveMemory activeMemory) {
		synchronized (memoryLock) {
			this.memory = activeMemory;
		}
	}
}
