package de.unibi.airobots.bonsai.xcf.actuators;

import java.io.IOException;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

import net.sf.xcf.MethodNotFoundException;
import net.sf.xcf.RemoteServer;
import net.sf.xcf.UserException;
import net.sf.xcf.transport.XOPData;
import nu.xom.Attribute;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;

import de.unibi.airobots.bonsai.actuators.EnterArenaAndLocalizeActuator;
import de.unibi.airobots.bonsai.actuators.StartStopActuator;
import de.unibi.airobots.bonsai.xcf.RemoteServerReconnectable;

/**
 * Start or stop processing of component by calling xcf server methods.
 * 
 * @author lziegler
 */
public class XcfStartStopActuator implements StartStopActuator,
        RemoteServerReconnectable {

    private Logger logger = Logger.getLogger(getClass());

    private String remoteServerName = "";
    private Object remoteServerLock = new Object();
    private RemoteServer remoteServer = null;

    /**
     * Constructor.
     * 
     * @param remoteServerName
     *            name of remote server
     */
    public XcfStartStopActuator(String remoteServerName) {
        this.remoteServerName = remoteServerName;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, ErrorHandlingPolicy> getRemoteServerNames() {
        Map<String, ErrorHandlingPolicy> servers =
                new HashMap<String, ErrorHandlingPolicy>();
        servers.put(remoteServerName, ErrorHandlingPolicy.SELF_HEALING);
        return servers;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void resetRemoteServer(RemoteServer remoteServer) {
        assert remoteServer.getServerName().equals(remoteServerName);
        synchronized (remoteServerLock) {
            this.remoteServer = remoteServer;
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void startProcessing() throws IOException {

        try {
            synchronized (remoteServerLock) {

                if (remoteServer == null) {
                    throw new IllegalStateException("No remote server set.");
                }
                Element elem = new Element("foo");
                Document doc = new Document(elem);
                remoteServer.callMethod("start", new XOPData(doc));
            }
        } catch (MethodNotFoundException e) {
            logger.error(e);
            throw new IOException(e);
        } catch (UserException e) {
            logger.error(e);
            throw new IOException(e);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void stopProcessing() throws IOException {
        try {
            synchronized (remoteServerLock) {

                if (remoteServer == null) {
                    throw new IllegalStateException("No remote server set.");
                }
                Element elem = new Element("foo");
                Document doc = new Document(elem);
                remoteServer.callMethod("stop", new XOPData(doc));
            }
        } catch (MethodNotFoundException e) {
            logger.error(e);
            throw new IOException(e);
        } catch (UserException e) {
            logger.error(e);
            throw new IOException(e);
        }
    }
}
